@@ -3,7 +3,7 @@ inner/outer elliptic/square reliefs for any kivy widget
 =======================================================
 
 The :class:`ReliefCanvas` mixin class of this ae namespace portion can be added to any square or elliptic Kivy widget
-for to draw a inner and/or outer relief, in order to convert your widget to have an outstanding or sunken 3D-optic.
+for to draw a inner and/or outer relief, in order to convert your widget to have an outstanding or sunken 3D-appearance.
 """
 from typing import Any, Callable, Tuple, Union
 
@@ -11,10 +11,10 @@ from kivy.graphics import Color, Line
 from kivy.factory import Factory                                                            # type: ignore
 # pylint: disable=no-name-in-module
 from kivy.graphics.instructions import InstructionGroup                                     # type: ignore # noqa: E0611
-from kivy.properties import NumericProperty, ObjectProperty                                 # type: ignore # noqa: E0611
+from kivy.properties import ListProperty, NumericProperty, ObjectProperty                   # type: ignore # noqa: E0611
 
 
-__version__ = '0.1.3'
+__version__ = '0.1.6'
 
 
 ANGLE_BEG = 87
@@ -52,11 +52,11 @@ def relief_colors(color_or_ink: ColorOrInk = (0, 0, 0), darken_factors: ReliefBr
         lightened_color = (1.0, 1.0, 1.0)
     else:
         brighten_factor = 1 / max_col_part
-        lightened_color = tuple([(col * brighten_factor) for col in color_or_ink[:3]])          # type: ignore # mypy
-    return tuple([tuple([col_part * darken for col_part in lightened_color]) for darken in darken_factors])
+        lightened_color = tuple((col * brighten_factor) for col in color_or_ink[:3])            # type: ignore # mypy
+    return tuple(tuple(col_part * darken for col_part in lightened_color) for darken in darken_factors)
 
 
-class ReliefCanvas:     # (Widget):     # also works without Widget/any ancestor
+class ReliefCanvas:                                                                             # pragma: no cover
     """ relief canvas mixin class.
 
     For to activate the drawing of a relief you have to specify two colors, one for the top part and another one
@@ -84,111 +84,108 @@ class ReliefCanvas:     # (Widget):     # also works without Widget/any ancestor
     (:attr:`.relief_ellipse_inner_colors`).
 
     The depth of the outer raise/sunk effect can be controlled with the :attr:`.relief_square_outer_lines`
-    property/attribute. :attr:`.relief_square_inner_lines` controls the raise/sunk depth of the inner surface
-    of a square widget. :attr:`.relief_ellipse_inner_lines` and :attr:`.relief_ellipse_outer_lines` are doing
-    the same for widgets with a round/elliptic shape.
+    property/attribute. :attr:`.relief_square_inner_lines` controls the raise/sunk depth of the inner surface of a
+    square widget. :attr:`.relief_ellipse_inner_lines` and :attr:`.relief_ellipse_outer_lines` are doing the same for
+    widgets with a round/elliptic shape.
 
-    The properties :attr:`.relief_square_inner_offset` and :attr:`.relief_ellipse_inner_offset` are specifying
-    the width of the widget border (the part between the outer and the inner relief) in pixels.
+    The properties :attr:`.relief_square_inner_offset` and :attr:`.relief_ellipse_inner_offset` are specifying the width
+    of the widget border (the part between the outer and the inner relief) in pixels.
 
     .. note::
         At least one of the classes that is mixing in this class has to inherit from Widget (or EventDispatcher) to get
         the widgets `pos`, `size`, `canvas` properties and the `bind` method.
+    """
 
+    relief_pos_size = ListProperty([])
+    """ tuple/list of optional relief position and size (x, y, width, height) in pixels.
+
+    If not specified or empty list/tuple, than the pos/size values of the mixing-in widget will be used instead.
+
+    :attr:`relief_pos_size` is a :class:`~kivy.properties.ListProperty` and defaults to an empty list/tuple.
     """
 
     relief_ellipse_inner_colors: ReliefColors = ObjectProperty(())
     """ tuple/list of ellipse inner (top, bottom) rgb colors.
 
-    :attr:`relief_ellipse_inner_colors` is a :class:`~kivy.properties.ObjectProperty` and
-    defaults to an empty list/tuple.
+    :attr:`relief_ellipse_inner_colors` is a :class:`~kivy.properties.ObjectProperty` and defaults to an empty tuple.
     """
 
-    relief_ellipse_inner_lines: NumericProperty = NumericProperty('3sp')
+    relief_ellipse_inner_lines = NumericProperty('3sp')
     """ number of ellipse inner lines/pixels to be drawn.
 
-    :attr:`relief_ellipse_inner_lines` is a :class:`~kivy.properties.NumericProperty` and
-    defaults to '3sp'.
+    :attr:`relief_ellipse_inner_lines` is a :class:`~kivy.properties.NumericProperty` and defaults to '3sp'.
     """
 
-    relief_ellipse_inner_offset: NumericProperty = NumericProperty('1sp')
+    relief_ellipse_inner_offset = NumericProperty('1sp')
     """ number of pixels left unchanged at the border of the inner elliptic surface before the inner relief starts.
 
-    :attr:`relief_ellipse_inner_offset` is a :class:`~kivy.properties.NumericProperty` and
-    defaults to '1sp'.
+    :attr:`relief_ellipse_inner_offset` is a :class:`~kivy.properties.NumericProperty` and defaults to '1sp'.
     """
 
     relief_ellipse_outer_colors: ReliefColors = ObjectProperty(())
     """ tuple/list of ellipse outer (top, bottom) rgb colors.
 
-    :attr:`relief_ellipse_outer_colors` is a :class:`~kivy.properties.ObjectProperty` and
-    defaults to an empty list/tuple.
+    :attr:`relief_ellipse_outer_colors` is a :class:`~kivy.properties.ObjectProperty` and defaults to an empty tuple.
     """
 
-    relief_ellipse_outer_lines: NumericProperty = NumericProperty('3sp')
+    relief_ellipse_outer_lines = NumericProperty('3sp')
     """ number of ellipse outer lines/pixels to be drawn.
 
-    :attr:`relief_ellipse_outer_lines` is a :class:`~kivy.properties.NumericProperty` and
-    defaults to '3sp'.
+    :attr:`relief_ellipse_outer_lines` is a :class:`~kivy.properties.NumericProperty` and defaults to '3sp'.
     """
 
-    relief_square_inner_colors: ReliefColors = ObjectProperty(())
+    relief_square_inner_colors = ObjectProperty(())
     """ tuple/list of square inner (top, bottom) rgb colors.
 
-    :attr:`relief_square_inner_colors` is a :class:`~kivy.properties.ObjectProperty` and
-    defaults to an empty list/tuple.
+    :attr:`relief_square_inner_colors` is a :class:`~kivy.properties.ObjectProperty` and defaults to an empty tuple.
     """
 
-    relief_square_inner_lines: NumericProperty = NumericProperty('3sp')
+    relief_square_inner_lines = NumericProperty('3sp')
     """ number of square inner lines/pixels to be drawn.
 
-    :attr:`relief_square_inner_lines` is a :class:`~kivy.properties.NumericProperty` and
-    defaults to '3sp'.
+    :attr:`relief_square_inner_lines` is a :class:`~kivy.properties.NumericProperty` and defaults to '3sp'.
     """
 
-    relief_square_inner_offset: NumericProperty = NumericProperty('1sp')
+    relief_square_inner_offset = NumericProperty('1sp')
     """ number of pixels left unchanged at the border of the square inner surface before the inner relief starts.
 
-    :attr:`relief_square_inner_offset` is a :class:`~kivy.properties.NumericProperty` and
-    defaults to '1sp'.
+    :attr:`relief_square_inner_offset` is a :class:`~kivy.properties.NumericProperty` and defaults to '1sp'.
     """
 
     relief_square_outer_colors: ReliefColors = ObjectProperty(())
     """ tuple of square outer (top, bottom) rgb colors.
 
-    :attr:`relief_square_outer_colors` is a :class:`~kivy.properties.ObjectProperty` and
-    defaults to an empty list/tuple.
+    :attr:`relief_square_outer_colors` is a :class:`~kivy.properties.ObjectProperty` and defaults to an empty tuple.
     """
 
     relief_square_outer_lines: NumericProperty = NumericProperty('3sp')
     """ number of square outer lines/pixels to be drawn.
 
-    :attr:`relief_square_outer_lines` is a :class:`~kivy.properties.NumericProperty` and
-    defaults to '3sp'.
+    :attr:`relief_square_outer_lines` is a :class:`~kivy.properties.NumericProperty` and defaults to '3sp'.
     """
 
     # attributes provided by the class to be mixed into
-    x: float
-    y: float
-    width: float
-    height: float
-    canvas: Any
     bind: Any
+    canvas: Any
+    pos: list
+    size: list
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.bind(pos=self._relief_refresh)
-        self.bind(size=self._relief_refresh)
-        self.bind(relief_ellipse_inner_colors=self._relief_refresh)
-        self.bind(relief_ellipse_inner_lines=self._relief_refresh)
-        self.bind(relief_ellipse_inner_offset=self._relief_refresh)
-        self.bind(relief_ellipse_outer_colors=self._relief_refresh)
-        self.bind(relief_ellipse_outer_lines=self._relief_refresh)
-        self.bind(relief_square_inner_colors=self._relief_refresh)
-        self.bind(relief_square_inner_lines=self._relief_refresh)
-        self.bind(relief_square_inner_offset=self._relief_refresh)
-        self.bind(relief_square_outer_colors=self._relief_refresh)
-        self.bind(relief_square_outer_lines=self._relief_refresh)
+        bind_func, bound_func = self.bind, self._relief_refresh
+        bind_func(pos=bound_func)
+        bind_func(size=bound_func)
+        bind_func(relief_pos_size=bound_func)
+        bind_func(relief_ellipse_inner_colors=bound_func)
+        bind_func(relief_ellipse_inner_lines=bound_func)
+        bind_func(relief_ellipse_inner_offset=bound_func)
+        bind_func(relief_ellipse_outer_colors=bound_func)
+        bind_func(relief_ellipse_outer_lines=bound_func)
+        bind_func(relief_square_inner_colors=bound_func)
+        bind_func(relief_square_inner_lines=bound_func)
+        bind_func(relief_square_inner_offset=bound_func)
+        bind_func(relief_square_outer_colors=bound_func)
+        bind_func(relief_square_outer_lines=bound_func)
 
         self._relief_graphic_instructions = InstructionGroup()
 
@@ -199,7 +196,7 @@ class ReliefCanvas:     # (Widget):     # also works without Widget/any ancestor
             self._relief_graphic_instructions.clear()
 
         add = self._relief_graphic_instructions.add
-        pos_size = self.x, self.y, self.width, self.height
+        pos_size = self.relief_pos_size or (*self.pos, *self.size)
         if self.relief_ellipse_inner_colors and self.relief_ellipse_inner_lines:
             self._relief_ellipse_inner_refresh(add, *self.relief_ellipse_inner_colors, *pos_size)
         if self.relief_ellipse_outer_colors and self.relief_ellipse_outer_lines:
